@@ -28,7 +28,7 @@ def maximize_number_of_file_descriptors():
         win32file._setmaxstdio(2048)
 
 # If DF is not supplied, no histograms are generated.
-def quality_report(analytics, df=None, rep=None):
+def quality_report(analytics, df=None, rep=None, show_correlations=True):
     maximize_number_of_file_descriptors()
     # Need this so it finds custom fonts
     font_manager._rebuild()
@@ -53,7 +53,7 @@ def quality_report(analytics, df=None, rep=None):
     all_stats = analytics.product_stats(provider_names_from_report(rep))
     data_stats_diagram(analytics, rep)
     distribution_diagrams(analytics, rep, all_stats)
-    generate_html(analytics, df, rep, all_stats)
+    generate_html(analytics, df, rep, all_stats, show_correlations)
     copy_files(here_dir)
     pdf_from_html("report/index.html", "report/report.pdf")
     print("Done.")
@@ -92,7 +92,7 @@ def data_stats_diagram(analytics, rep):
     patches, texts = plt.pie(values, colors=data_stats_colors())
     return save_figure("data_stats")
 
-def generate_html(analytics, df, rep, all_stats):
+def generate_html(analytics, df, rep, all_stats, show_correlations):
     doc = Doc()
     with doc.tag("html"):
         with doc.tag("head"):
@@ -106,8 +106,8 @@ def generate_html(analytics, df, rep, all_stats):
             page_break(doc)
             header(doc)
             data_stats_section(analytics, rep, doc)
-            # Only plot correlations if we have a DF
-            if isinstance(df, pd.DataFrame) and (len(df) >= 2):
+            # Only plot correlations if we have a DF and correlations flag is True.
+            if isinstance(df, pd.DataFrame) and (len(df) >= 2) and show_correlations:
                 page_break(doc)
                 header(doc)
                 correlations_section(analytics, df, rep, doc)
